namespace elm { namespace interface { 
inline ::efl::eolian::return_traits<bool>::type Fileselector::folder_only_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_folder_only_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::folder_only_set( ::efl::eolian::in_traits<bool>::type only) const
{
    ::elm_interface_fileselector_folder_only_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(only));
}
inline ::efl::eolian::return_traits<void>::type Fileselector::thumbnail_size_get( ::efl::eolian::out_traits<Evas_Coord>::type w,  ::efl::eolian::out_traits<Evas_Coord>::type h) const
{
   Evas_Coord __out_param_w = {};
   Evas_Coord __out_param_h = {};
    ::elm_interface_fileselector_thumbnail_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::thumbnail_size_set( ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::elm_interface_fileselector_thumbnail_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::hidden_visible_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_hidden_visible_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::hidden_visible_set( ::efl::eolian::in_traits<bool>::type multi) const
{
    ::elm_interface_fileselector_hidden_visible_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(multi));
}
inline ::efl::eolian::return_traits<Elm_Fileselector_Sort>::type Fileselector::sort_method_get() const
{
   Elm_Fileselector_Sort __return_value =  ::elm_interface_fileselector_sort_method_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Fileselector_Sort>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::sort_method_set( ::efl::eolian::in_traits<Elm_Fileselector_Sort>::type sort) const
{
    ::elm_interface_fileselector_sort_method_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Sort,  ::efl::eolian::in_traits<Elm_Fileselector_Sort>::type>(sort));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::multi_select_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_multi_select_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::multi_select_set( ::efl::eolian::in_traits<bool>::type multi) const
{
    ::elm_interface_fileselector_multi_select_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(multi));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::expandable_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_expandable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::expandable_set( ::efl::eolian::in_traits<bool>::type expand) const
{
    ::elm_interface_fileselector_expandable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(expand));
}
inline ::efl::eolian::return_traits< ::efl::Model>::type Fileselector::model_get() const
{
    ::Efl_Model* __return_value =  ::elm_interface_fileselector_model_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Model>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::model_set( ::efl::eolian::in_traits< ::efl::Model>::type model) const
{
    ::elm_interface_fileselector_model_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Model*,  ::efl::eolian::in_traits< ::efl::Model>::type>(model));
}
inline ::efl::eolian::return_traits<Elm_Fileselector_Mode>::type Fileselector::mode_get() const
{
   Elm_Fileselector_Mode __return_value =  ::elm_interface_fileselector_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Fileselector_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::mode_set( ::efl::eolian::in_traits<Elm_Fileselector_Mode>::type mode) const
{
    ::elm_interface_fileselector_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Mode,  ::efl::eolian::in_traits<Elm_Fileselector_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::is_save_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_is_save_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::is_save_set( ::efl::eolian::in_traits<bool>::type is_save) const
{
    ::elm_interface_fileselector_is_save_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(is_save));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::efl::Model>>::type Fileselector::selected_models_get() const
{
   const Eina_List * __return_value =  ::elm_interface_fileselector_selected_models_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::efl::Model>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Fileselector::current_name_get() const
{
   const char * __return_value =  ::elm_interface_fileselector_current_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::current_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::elm_interface_fileselector_current_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits<void>::type Fileselector::selected_model_set( ::efl::eolian::in_traits< ::efl::Model>::type model,  ::efl::eolian::inout_traits< ::efl::eina::future< ::efl::Model>>::type promise) const
{
   Eina_Promise * __out_param_promise = ::efl::eolian::convert_inout<Eina_Promise *,  ::efl::eina::future< ::efl::Model>>(promise);
    ::elm_interface_fileselector_selected_model_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Model*,  ::efl::eolian::in_traits< ::efl::Model>::type>(model)
      , & __out_param_promise);
   ::efl::eolian::assign_out< ::efl::eolian::inout_traits< ::efl::eina::future< ::efl::Model>>::type, Eina_Promise *>(promise, __out_param_promise);
}
inline ::efl::eolian::return_traits< ::efl::Model>::type Fileselector::selected_model_get() const
{
    ::Efl_Model* __return_value =  ::elm_interface_fileselector_selected_model_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Model>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::custom_filter_append( ::efl::eolian::in_traits<Elm_Fileselector_Filter_Func>::type func,  ::efl::eolian::in_traits<void*>::type data,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type filter_name) const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_custom_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Filter_Func,  ::efl::eolian::in_traits<Elm_Fileselector_Filter_Func>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(filter_name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::filters_clear() const
{
    ::elm_interface_fileselector_filters_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::mime_types_filter_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type mime_types,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type filter_name) const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_mime_types_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(mime_types)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(filter_name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace elm { namespace interface { 
inline ::efl::eolian::return_traits<bool>::type Fileselector::folder_only_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_folder_only_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::folder_only_set( ::efl::eolian::in_traits<bool>::type only) const
{
    ::elm_interface_fileselector_folder_only_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(only));
}
inline ::efl::eolian::return_traits<void>::type Fileselector::thumbnail_size_get( ::efl::eolian::out_traits<Evas_Coord>::type w,  ::efl::eolian::out_traits<Evas_Coord>::type h) const
{
   Evas_Coord __out_param_w = {};
   Evas_Coord __out_param_h = {};
    ::elm_interface_fileselector_thumbnail_size_get(this->_eo_ptr()
      , & __out_param_w
      , & __out_param_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(w, __out_param_w);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Evas_Coord>::type, Evas_Coord>(h, __out_param_h);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::thumbnail_size_set( ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::elm_interface_fileselector_thumbnail_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::hidden_visible_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_hidden_visible_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::hidden_visible_set( ::efl::eolian::in_traits<bool>::type multi) const
{
    ::elm_interface_fileselector_hidden_visible_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(multi));
}
inline ::efl::eolian::return_traits<Elm_Fileselector_Sort>::type Fileselector::sort_method_get() const
{
   Elm_Fileselector_Sort __return_value =  ::elm_interface_fileselector_sort_method_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Fileselector_Sort>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::sort_method_set( ::efl::eolian::in_traits<Elm_Fileselector_Sort>::type sort) const
{
    ::elm_interface_fileselector_sort_method_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Sort,  ::efl::eolian::in_traits<Elm_Fileselector_Sort>::type>(sort));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::multi_select_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_multi_select_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::multi_select_set( ::efl::eolian::in_traits<bool>::type multi) const
{
    ::elm_interface_fileselector_multi_select_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(multi));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::expandable_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_expandable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::expandable_set( ::efl::eolian::in_traits<bool>::type expand) const
{
    ::elm_interface_fileselector_expandable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(expand));
}
inline ::efl::eolian::return_traits< ::efl::Model>::type Fileselector::model_get() const
{
    ::Efl_Model* __return_value =  ::elm_interface_fileselector_model_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Model>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::model_set( ::efl::eolian::in_traits< ::efl::Model>::type model) const
{
    ::elm_interface_fileselector_model_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Model*,  ::efl::eolian::in_traits< ::efl::Model>::type>(model));
}
inline ::efl::eolian::return_traits<Elm_Fileselector_Mode>::type Fileselector::mode_get() const
{
   Elm_Fileselector_Mode __return_value =  ::elm_interface_fileselector_mode_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Fileselector_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::mode_set( ::efl::eolian::in_traits<Elm_Fileselector_Mode>::type mode) const
{
    ::elm_interface_fileselector_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Mode,  ::efl::eolian::in_traits<Elm_Fileselector_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::is_save_get() const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_is_save_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::is_save_set( ::efl::eolian::in_traits<bool>::type is_save) const
{
    ::elm_interface_fileselector_is_save_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(is_save));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::efl::Model>>::type Fileselector::selected_models_get() const
{
   const Eina_List * __return_value =  ::elm_interface_fileselector_selected_models_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::efl::Model>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Fileselector::current_name_get() const
{
   const char * __return_value =  ::elm_interface_fileselector_current_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::current_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
    ::elm_interface_fileselector_current_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
}
inline ::efl::eolian::return_traits<void>::type Fileselector::selected_model_set( ::efl::eolian::in_traits< ::efl::Model>::type model,  ::efl::eolian::inout_traits< ::efl::eina::future< ::efl::Model>>::type promise) const
{
   Eina_Promise * __out_param_promise = ::efl::eolian::convert_inout<Eina_Promise *,  ::efl::eina::future< ::efl::Model>>(promise);
    ::elm_interface_fileselector_selected_model_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Model*,  ::efl::eolian::in_traits< ::efl::Model>::type>(model)
      , & __out_param_promise);
   ::efl::eolian::assign_out< ::efl::eolian::inout_traits< ::efl::eina::future< ::efl::Model>>::type, Eina_Promise *>(promise, __out_param_promise);
}
inline ::efl::eolian::return_traits< ::efl::Model>::type Fileselector::selected_model_get() const
{
    ::Efl_Model* __return_value =  ::elm_interface_fileselector_selected_model_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Model>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::custom_filter_append( ::efl::eolian::in_traits<Elm_Fileselector_Filter_Func>::type func,  ::efl::eolian::in_traits<void*>::type data,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type filter_name) const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_custom_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Fileselector_Filter_Func,  ::efl::eolian::in_traits<Elm_Fileselector_Filter_Func>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(filter_name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Fileselector::filters_clear() const
{
    ::elm_interface_fileselector_filters_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<bool>::type Fileselector::mime_types_filter_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type mime_types,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type filter_name) const
{
   Eina_Bool __return_value =  ::elm_interface_fileselector_mime_types_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(mime_types)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(filter_name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline elm::interface::Fileselector::operator ::elm::interface::Fileselector() const { return *static_cast< ::elm::interface::Fileselector const*>(static_cast<void const*>(this)); }
inline elm::interface::Fileselector::operator ::elm::interface::Fileselector&() { return *static_cast< ::elm::interface::Fileselector*>(static_cast<void*>(this)); }
inline elm::interface::Fileselector::operator ::elm::interface::Fileselector const&() const { return *static_cast< ::elm::interface::Fileselector const*>(static_cast<void const*>(this)); }
} } }

